Skip to contents

Replaces latent common causes with correlated response function variables

Usage

dhvm_canonical_partition(dag)

Arguments

dag

An object of class "dhvm" representing a dag

Value

A modified object with response function variables for each observed variable

Examples


# classic IV model

ivd <- dhvm(caugi(Z %-->% X %-->% Y, U %-->% X + Y))
ivdcp <- dhvm_canonical_partition(ivd)