Skip to contents

The districts of a DHVM are the sets of nodes that remain connected after removing all edges that have tails at observed nodes. The set of districts forms a partition of the variables in the model.

Usage

dhvm_districts(dhvm)

Arguments

dhvm

A object of class dhvm

Value

A list of character vectors

Examples

dhvm_districts(dhvm(caugi(U1 %-->% X + Y, U2 %-->% Z + X)))
#> [[1]]
#> [1] "X"  "Y"  "Z"  "U1" "U2"
#> 
dhvm_districts(dhvm(caugi(Z %-->% X %-->% Y, U1 %-->% X + Y)))
#> [[1]]
#> [1] "Z"
#> 
#> [[2]]
#> [1] "X"  "Y"  "U1"
#>