Get constraints implied by a discrete hidden variables model
Source:R/dhvm-to-constraints.R
meraconstraints.RdGet constraints implied by a discrete hidden variables model
Examples
ivd <- dhvm(caugi(Z %-->% X %-->% Y, U %-->% X + Y))
meraconstraints(ivd)
#> MERA constraints on the dhvm: ivd
#> The model has districts (unobserved variables marked with [u]:
#> {Z} with c-degree 1, {X, Y, U[u]} with c-degree 1
#> The canonical partitioned model is available in x$dhvm_partitioned
#>
#> Constraints:
#> ------------
#> There are no conditional independence relations.
#> * Equality and inequality constraints by district:
#> There are 4 possibly nontrivial constraints involving X_Y, 4 inequalities and 0 equalities.
#> The first 4 expressions are
#> -P(X = 0|Z = 0)P(Y = 0|X = 0,Z = 0) - P(X = 1|Z = 0)P(Y = 0| ...[truncated]
#> P(X = 1|Z = 0)P(Y = 0|X = 1,Z = 0) - P(X = 0|Z = 1)P(Y = 0|X ...[truncated]
#> P(X = 0|Z = 0)P(Y = 1|X = 0,Z = 0) + P(X = 0|Z = 1)P(Y = 0|X ...[truncated]
#> P(X = 0|Z = 0)P(Y = 0|X = 0,Z = 0) + P(X = 0|Z = 1)P(Y = 1|X ...[truncated]