Transform a regular dag into canonical partitions and add response function tables
Source:R/dhvm-to-constraints.R
dhvm_canonical_partition.RdReplaces latent common causes with correlated response function variables
Examples
# classic IV model
ivd <- dhvm(caugi(Z %-->% X %-->% Y, U %-->% X + Y))
ivdcp <- dhvm_canonical_partition(ivd)